@@ -8,7 +8,7 @@ function (object, ...)
 }
 "anova.rqlist" <-
 function (object, ..., test = "Wald", joint = TRUE, 
-		score = "tau", R = 200, trim = NULL) 
+		score = "tau", se = "nid", R = 200, trim = NULL) 
 {
     objects <- list(object, ...)
     responses <- as.character(lapply(objects, function(x) formula(x)[[2]]))
@@ -28,7 +28,7 @@ function (object, ..., test = "Wald", joint = TRUE,
     else
     	names <- lapply(objects, function(x) names(coef(x)))
     if (test == "Wald") 
-        objects <- lapply(objects, function(x) summary(x,se="nid",covariance = TRUE))
+        objects <- lapply(objects, function(x) summary(x,se=se,covariance = TRUE))
     sametaus <- taus == taus[[1]]
     if (all(sametaus)) {
         Tn <- rep(0, nobjects - 1)
